@@ -3,13 +3,14 @@ import os
 import os.path
 import sys
 import typing
+import warnings
 
 import glfw
 import skia
 
-from ..event import SkEvent, SkEventHanding
+from ..event import SkEvent, SkEventHandling
 from ..misc import SkMisc
-from .appbase import SkAppBase
+from . import SkAppBase
 
 
 class _GLFW_IMAGE:
@@ -26,7 +27,7 @@ class _GLFW_IMAGE:
         self.image.convert(colorType=skia.ColorType.kRGBA_8888_ColorType)
 
 
-class SkWindowBase(SkEventHanding, SkMisc):
+class SkWindowBase(SkEventHandling, SkMisc):
     """Base Window class
 
     Example:
@@ -62,7 +63,7 @@ class SkWindowBase(SkEventHanding, SkMisc):
         self.id = self.__class__.__name__ + str(self._instance_count + 1)
         self.children = []
 
-        SkEventHanding.__init__(self)
+        SkEventHandling.__init__(self)
         self.parent: SkAppBase | typing.Self | int = (
             parent if parent is not None else SkAppBase.get_instance()
         )
@@ -87,6 +88,7 @@ class SkWindowBase(SkEventHanding, SkMisc):
         self._event_init = False  #
         self._cursor = None
         self.cursors = {}
+        self.mode: typing.Literal["normal", "input"] = "normal"
 
         # Always is 0
         self.x: int | float = 0
@@ -124,35 +126,18 @@ class SkWindowBase(SkEventHanding, SkMisc):
             "minsize": minsize,
         }
 
-        self.events = {
-            # Mouse Events
-            "mouse_move": {},
-            "mouse_motion": {},
-            "mouse_pressed": {},
-            "mouse_released": {},
-            "mouse_enter": {},
-            "mouse_leave": {},
-            "scroll": {},
-            # Keyboard Events
-            "key_pressed": {},
-            "key_released": {},
-            "key_repeated": {},
-            "char": {},
-            # Window Events
-            "focus_gain": {},
-            "focus_loss": {},
-            "resize": {},
-            "drop": {},
-            "maximize": {},
-            "iconify": {},
-            "configure": {},
-            "dpi_change": {},  # 添加DPI变化事件
-            "delete_window": {},
-            # Unlike the `closed` event, `delete_window` is triggered when the window is not yet destroyed but the user attempts to close it.
-            "closed": {},
-            "move": {},
-            "update": {},
-        }
+        [
+            self.EVENT_TYPES.append(event_type)
+            for event_type in [
+                "drop",
+                "maximize",
+                "iconify",
+                "dpi_change",
+                "delete_window",
+                "closed",
+                "move",
+            ]
+        ]
 
         buttons = [
             "button1",
@@ -162,11 +147,11 @@ class SkWindowBase(SkEventHanding, SkMisc):
             "b2",
             "b3",
         ]  # Left Right Middle
-        button_states = ["pressed", "released", "motion", "move"]
+        button_states = ["press", "release", "motion", "move"]
 
         for button in buttons:
             for state in button_states:
-                self.event_generate(f"{button}_{state}")
+                self.trigger(f"button_{state}[{button}]")
 
         SkWindowBase._instance_count += 1
 
@@ -175,15 +160,16 @@ class SkWindowBase(SkEventHanding, SkMisc):
         self.surface = None
         self.attributes["fullscreen"] = fullscreen
         self.is_mouse_floating = False
+        self.is_mouse_press = False
 
         if self.width <= 0 or self.height <= 0:
             raise ValueError("The window size must be positive")
 
         ####################
 
-        self.is_mouse_pressed = False
-
         self.the_window = self.create()
+        self.alive = True
+        self.create_bind()
 
         # self.cursor(self.default_cursor())
 
@@ -238,6 +224,9 @@ class SkWindowBase(SkEventHanding, SkMisc):
                     else:
                         monitor = None
 
+                    glfw.window_hint(
+                        glfw.CONTEXT_RELEASE_BEHAVIOR, glfw.RELEASE_BEHAVIOR_NONE
+                    )  # mystery optimize
                     glfw.window_hint(glfw.STENCIL_BITS, 8)
                     glfw.window_hint(glfw.COCOA_RETINA_FRAMEBUFFER, glfw.TRUE)  # macOS
                     glfw.window_hint(glfw.SCALE_TO_MONITOR, glfw.TRUE)  # Windows/Linux
@@ -254,9 +243,7 @@ class SkWindowBase(SkEventHanding, SkMisc):
                             glfw.window_hint(glfw.CLIENT_API, glfw.OPENGL_API)
                             glfw.window_hint(glfw.CONTEXT_VERSION_MAJOR, 3)
                             glfw.window_hint(glfw.CONTEXT_VERSION_MINOR, 3)
-                            glfw.window_hint(
-                                glfw.OPENGL_PROFILE, glfw.OPENGL_CORE_PROFILE
-                            )
+                            glfw.window_hint(glfw.OPENGL_PROFILE, glfw.OPENGL_CORE_PROFILE)
 
                     window = glfw.create_window(
                         self.width, self.height, self.cget("title"), monitor, None
@@ -287,17 +274,13 @@ class SkWindowBase(SkEventHanding, SkMisc):
                         sdl2.SDL_WINDOWPOS_CENTERED,
                         self.width,
                         self.height,
-                        sdl2.SDL_WINDOW_OPENGL
-                        | sdl2.SDL_WINDOW_SHOWN
-                        | sdl2.SDL_WINDOW_RESIZABLE,
+                        sdl2.SDL_WINDOW_OPENGL | sdl2.SDL_WINDOW_SHOWN | sdl2.SDL_WINDOW_RESIZABLE,
                     )
 
                     self.visible = True
             return window
         else:
-            raise RuntimeError(
-                "The window must be added to the Application instance first"
-            )
+            raise RuntimeError("The window must be added to the Application instance first")
 
     def create_bind(self) -> None:
         """Binding glfw window events.
@@ -310,9 +293,7 @@ class SkWindowBase(SkEventHanding, SkMisc):
                 case "glfw":
                     glfw.make_context_current(window)
                     glfw.set_window_size_callback(window, self._on_resizing)
-                    glfw.set_framebuffer_size_callback(
-                        window, self._on_framebuffer_size
-                    )
+                    glfw.set_framebuffer_size_callback(window, self._on_framebuffer_size)
                     glfw.set_window_close_callback(window, self._on_closed)
                     glfw.set_mouse_button_callback(window, self._on_mouse_button)
                     glfw.set_cursor_enter_callback(window, self._on_cursor_enter)
@@ -328,13 +309,33 @@ class SkWindowBase(SkEventHanding, SkMisc):
                     glfw.set_scroll_callback(window, self._on_scroll)
                     glfw.set_window_content_scale_callback(window, self._on_dpi_change)
                 case "sdl2":
-                    import sdl2
+                    print("TODO: implement sdl2 `create_bind`")
             self._event_init = True
 
     # endregion
 
     # region Draw 绘制相关
 
+    def update(self, redraw: bool = False) -> None:
+        """Update window.
+
+        :param bool redraw: Whether to redraw the window.
+        """
+        if self.visible:
+            self.trigger("update", SkEvent(event_type="update"))
+
+            if self.mode == "input" or redraw:
+                self.draw()
+            else:
+                for child in self.children:
+                    if not isinstance(child, SkWindowBase):
+                        if child.need_redraw:
+                            self.draw()
+                            return
+
+            # self.update_layout: typing.Callable
+            # self.post()
+
     @contextlib.contextmanager
     def skia_surface(self, arg: typing.Any) -> skia.Surface:
         """Create a Skia surface for the window.
@@ -390,16 +391,14 @@ class SkWindowBase(SkEventHanding, SkMisc):
 
                 yield surface  # ⚠️ 必须用 yield，不要 return
 
-    def draw(self):
+    def draw(self, event: SkEvent = None) -> None:
         if self.visible:
             # Set the current context for each arg
             # 【为该窗口设置当前上下文】
             match self.framework:
                 case "glfw":
                     glfw.make_context_current(self.the_window)
-                    if self.context:
-                        self.context.freeGpuResources()
-                        self.context.releaseResourcesAndAbandonContext()
+
                     # Create a Surface and hand it over to this arg.
                     # 【创建Surface，交给该窗口】
                     with self.skia_surface(self.the_window) as self.surface:
@@ -411,8 +410,11 @@ class SkWindowBase(SkEventHanding, SkMisc):
                                     self.draw_func(canvas)
 
                             self.surface.flushAndSubmit()
-
-                    glfw.swap_buffers(self.the_window)
+                            self.trigger(
+                                "redrawing", SkEvent(self, "redrawing", surface=self.surface)
+                            )
+                    if self.alive:
+                        glfw.swap_buffers(self.the_window)
                 case "sdl2":
                     import sdl2
 
@@ -425,10 +427,46 @@ class SkWindowBase(SkEventHanding, SkMisc):
                                     self.draw_func(canvas)
 
                     sdl2.SDL_UpdateWindowSurface(self.the_window)
+        if self.context:
+            self.context.freeGpuResources()
+            self.context.releaseResourcesAndAbandonContext()
+        for child in self.children:
+            child.need_redraw = False
+        self.trigger("redraw", SkEvent(self, "redraw"))
 
-    def save(self, path: str = "skwindowbase.png", format: str = "png"):
-        if self.surface:
-            self.surface.makeImageSnapshot().save(path, skia.kPNG)
+    def save(self, path: str = "snapshot.png", _format: str = "png"):
+        """Save a snapshot of the window.
+
+        :param path: Path to save the snapshot
+        :param _format: Format of the snapshot, default is "png"
+        :return: Whether the snapshot is saved successfully
+        """
+        if _format == "png":
+            _format = skia.kPNG
+        elif _format == "jpg":
+            _format = skia.kJPEG
+        elif _format == "webp":
+            _format = skia.kWEBP
+
+        self.image_snapshot = None
+
+        def _(evt):
+            self.image_snapshot = evt["surface"].makeImageSnapshot()
+            if self.surface:
+                snapshot = self.surface.makeImageSnapshot()
+                if snapshot:
+                    return snapshot.save(path, _format)
+                else:
+                    warnings.warn("Cannot save snapshot")
+            else:
+                warnings.warn("No surface to save")
+            return None
+
+        task_id = self.bind("redrawing", _)
+        self.draw(None)
+        self.unbind(task_id)
+
+    snapshot = save
 
     def set_draw_func(self, func: typing.Callable) -> "SkWindowBase":
         """Set the draw function.
@@ -439,16 +477,6 @@ class SkWindowBase(SkEventHanding, SkMisc):
         self.draw_func = func
         return self
 
-    def update(self) -> None:
-        """Update window.
-
-        :return: None
-        """
-        if self.visible:
-            self.event_trigger("update", SkEvent(event_type="update"))
-            self.update_layout()
-            # self.post()
-
     # endregion
 
     # region Event handling 事件处理
@@ -482,13 +510,11 @@ class SkWindowBase(SkEventHanding, SkMisc):
         :param char: Unicode character
         """
 
-        self.event_trigger(
-            "char", SkEvent(event_type="char", char=chr(char), glfw_window=window)
-        )
+        self.trigger("char", SkEvent(event_type="char", char=chr(char), glfw_window=window))
+        self.update()
+        # self.update(redraw=True)
 
-    def _on_key(
-        self, window: typing.Any, key: str, scancode: str, action: str, mods: int
-    ) -> None:
+    def _on_key(self, window: typing.Any, key: str, scancode: str, action: str, mods: int) -> None:
         """
         触发键盘事件
 
@@ -507,15 +533,15 @@ class SkWindowBase(SkEventHanding, SkMisc):
         # 我真尼玛服了啊，改了半天，发现delete键获取不到键名，卡了我半天啊
 
         if action == PRESS:
-            name = "key_pressed"
+            name = "key_press"
         elif action == RELEASE:
-            name = "key_released"
+            name = "key_release"
         elif action == REPEAT:
-            name = "key_repeated"
+            name = "key_repeat"
         else:
             name = "key"
         self.ime(100, 1000)
-        self.event_trigger(
+        self.trigger(
             name,
             SkEvent(
                 event_type=name,
@@ -526,6 +552,7 @@ class SkWindowBase(SkEventHanding, SkMisc):
                 glfw_window=window,
             ),
         )
+        self.update()
 
     def _on_focus(self, window, focused) -> None:
         """Triggers the focus event (triggered when the window gains or loses focus).
@@ -536,19 +563,14 @@ class SkWindowBase(SkEventHanding, SkMisc):
         """
         if focused:
             self.configure(focus=True)
-            self.event_trigger(
-                "focus_gain", SkEvent(event_type="focus_gain", glfw_window=window)
-            )
+            self.trigger("focus_gain", SkEvent(event_type="focus_gain", glfw_window=window))
+            self.update(redraw=True)
         else:
             self.configure(focus=False)
-            self.event_trigger(
-                "focus_loss", SkEvent(event_type="focus_loss", glfw_window=window)
-            )
+            self.trigger("focus_loss", SkEvent(event_type="focus_loss", glfw_window=window))
 
     def _on_refresh(self, window: typing.Any):
-        self.draw()
-        if hasattr(self, "update_layout"):
-            self.update_layout()
+        self.update(True)
 
     def _on_scroll(self, window, x_offset, y_offset):
         """Trigger scroll event (triggered when the mouse scroll wheel is scrolled).
@@ -558,7 +580,7 @@ class SkWindowBase(SkEventHanding, SkMisc):
         :param y_offset: Y offset
         :return: None
         """
-        self.event_trigger(
+        self.trigger(
             "scroll",
             SkEvent(
                 event_type="scroll",
@@ -569,7 +591,7 @@ class SkWindowBase(SkEventHanding, SkMisc):
         )
 
     def _on_framebuffer_size(self, window: typing.Any, width: int, height: int) -> None:
-        pass
+        self.update()
 
     def _on_resizing(self, window, width: int, height: int) -> None:
         """Trigger resize event (triggered when the window size changes).
@@ -588,13 +610,11 @@ class SkWindowBase(SkEventHanding, SkMisc):
         self.physical_width = int(width * self.dpi_scale)
         self.physical_height = int(height * self.dpi_scale)
 
-        event = SkEvent(
-            event_type="resize", width=width, height=height, dpi_scale=self.dpi_scale
-        )
-
-        self.event_trigger("resize", event)
+        event = SkEvent(event_type="resize", width=width, height=height, dpi_scale=self.dpi_scale)
+        self.trigger("resize", event)
         for child in self.children:
-            child.event_trigger("resize", event)
+            child.trigger("resize", event)
+        self.update(True)
         # cls.update()
 
     def _on_window_pos(self, window: typing.Any, x: int, y: int) -> None:
@@ -607,9 +627,7 @@ class SkWindowBase(SkEventHanding, SkMisc):
         """
         self.root_x = x
         self.root_y = y
-        self.event_trigger(
-            "move", SkEvent(event_type="move", x=x, y=y, glfw_window=window)
-        )
+        self.trigger("move", SkEvent(event_type="move", x=x, y=y, glfw_window=window))
 
     def _on_closed(self, window: typing.Any) -> None:
         """Trigger closed event (triggered when the window is closed).
@@ -617,20 +635,20 @@ class SkWindowBase(SkEventHanding, SkMisc):
         :param window: GLFW Window
         :return: None
         """
-        # self.event_trigger("closed", SkEvent(event_type="closed", the_window=window))
+        # self.trigger("closed", SkEvent(event_type="closed", the_window=window))
 
     def _on_mouse_button(
         self,
         window: typing.Any,
         button: typing.Literal[0, 1, 2],
-        is_pressed: bool,
+        is_press: bool,
         mods: int,
     ) -> None:
-        """Trigger mouse button event (triggered when the mouse button is pressed or released).
+        """Trigger mouse button event (triggered when the mouse button is press or release).
 
         :param window: GLFW Window
         :param int button: Button
-        :param is_pressed: Whether pressed
+        :param is_press: Whether press
         :param mods: Modifiers
         :return: None
         """
@@ -639,17 +657,24 @@ class SkWindowBase(SkEventHanding, SkMisc):
         self.mouse_x, self.mouse_y = self.mouse_pos()
         self.mouse_rootx, self.mouse_rooty = self.mouse_root_pos()
 
-        if is_pressed:
-            state = "pressed"
+        if is_press:
+            self.is_mouse_press = True
+            state = "press"
         else:
-            state = "released"
+            self.is_mouse_press = False
+            state = "release"
+            self.button = -1
 
-        names = [f"mouse_{state}", f"button{button+1}_{state}", f"b{button+1}_{state}"]
+        names = [
+            f"mouse_{state}",
+            f"mouse_{state}[button{button+1}]",
+            f"mouse_{state}[b{button+1}]",
+        ]
 
         self.button = button
 
         for name in names:
-            self.event_trigger(
+            self.trigger(
                 name,
                 SkEvent(
                     event_type=name,
@@ -661,8 +686,6 @@ class SkWindowBase(SkEventHanding, SkMisc):
                     mods=self.mods_name(mods),
                 ),
             )
-        if not is_pressed:
-            self.button = -1
 
     def _on_cursor_enter(self, window: typing.Any, is_enter: bool) -> None:
         """Trigger mouse enter event (triggered when the mouse enters the window) or mouse leave event (triggered when the mouse leaves the window).
@@ -676,7 +699,7 @@ class SkWindowBase(SkEventHanding, SkMisc):
 
         if is_enter:
             self.is_mouse_floating = True
-            self.event_trigger(
+            self.trigger(
                 "mouse_enter",
                 SkEvent(
                     event_type="mouse_enter",
@@ -688,7 +711,7 @@ class SkWindowBase(SkEventHanding, SkMisc):
             )
         else:
             self.is_mouse_floating = False
-            self.event_trigger(
+            self.trigger(
                 "mouse_leave",
                 SkEvent(
                     event_type="mouse_leave",
@@ -716,10 +739,14 @@ class SkWindowBase(SkEventHanding, SkMisc):
 
         button = self.button
         if button >= 0:
-            names = ["mouse_motion", f"button{button+1}_motion", f"b{button+1}_motion"]
+            names = [
+                "mouse_motion",
+                f"mouse_motion[button{button+1}]",
+                f"mouse_motion[b{button+1}]",
+            ]
 
             for name in names:
-                self.event_trigger(
+                self.trigger(
                     name,
                     SkEvent(
                         event_type=name,
@@ -730,7 +757,7 @@ class SkWindowBase(SkEventHanding, SkMisc):
                         glfw_window=window,
                     ),
                 )
-        self.event_trigger(
+        self.trigger(
             "mouse_move",
             SkEvent(
                 event_type="mouse_move",
@@ -743,18 +770,16 @@ class SkWindowBase(SkEventHanding, SkMisc):
         )
 
     def _on_maximize(self, window, maximized: bool):
-        self.event_trigger(
+        self.trigger(
             "maximize",
             SkEvent(event_type="maximize", maximized=maximized, glfw_window=window),
         )
 
     def _on_drop(self, window: typing.Any, paths):
-        self.event_trigger(
-            "drop", SkEvent(event_type="drop", paths=paths, glfw_window=window)
-        )
+        self.trigger("drop", SkEvent(event_type="drop", paths=paths, glfw_window=window))
 
     def _on_iconify(self, window: typing.Any, iconified: bool):
-        self.event_trigger(
+        self.trigger(
             "iconify",
             SkEvent(event_type="iconify", iconified=iconified, glfw_window=window),
         )
@@ -763,6 +788,7 @@ class SkWindowBase(SkEventHanding, SkMisc):
 
     # region Configure 属性配置
 
+    # TODO: wtf function name and docstring
     def ime(self, x: int = 9, y: int = 0):
         return
         if sys.platform == "win32":
@@ -830,6 +856,11 @@ class SkWindowBase(SkEventHanding, SkMisc):
             return set_candidate_pos(hwnd, 100, 200)
 
     def geometry(self, spec: str | None = None) -> str | typing.Self:
+        """Get or set the geometry of the window.
+
+        :param spec: Geometry specification string, such as "100x100+100+100"
+        :return: Geometry string if no argument is given, otherwise self
+        """
         if spec is None:
             return f"{self.width}x{self.height}+{self.root_x}+{self.root_y}"
 
@@ -887,9 +918,9 @@ class SkWindowBase(SkEventHanding, SkMisc):
         """
         glfw.request_window_attention(self.the_window)
 
-    ask_notice = ask_focus = hongwen = wm_ask_notice
+    ask_notice = ask_focus = wm_ask_notice
 
-    def wm_iconpath(self, path: str | str = None) -> str | None:
+    def wm_iconpath(self, path: str | None = None) -> str | None:
         if path:
             try:
                 import PIL
@@ -909,16 +940,12 @@ class SkWindowBase(SkEventHanding, SkMisc):
 
     iconpath = wm_iconpath
 
-    def wm_maxsize(
-        self, width: int | float | None = None, height: int | float | None = None
-    ):
+    def wm_maxsize(self, width: int | float | None = None, height: int | float | None = None):
         if width is None:
             width = glfw.DONT_CARE
         if height is None:
             height = glfw.DONT_CARE
-        glfw.set_window_size_limits(
-            self.the_window, glfw.DONT_CARE, glfw.DONT_CARE, width, height
-        )
+        glfw.set_window_size_limits(self.the_window, glfw.DONT_CARE, glfw.DONT_CARE, width, height)
 
     maxsize = wm_maxsize
 
@@ -1034,9 +1061,7 @@ class SkWindowBase(SkEventHanding, SkMisc):
         if name not in self.cursors:
             if custom_cursor is not None:
                 # 【自定义光标样式】
-                cursor = glfw.create_cursor(
-                    custom_cursor[0], custom_cursor[1], custom_cursor[2]
-                )
+                cursor = glfw.create_cursor(custom_cursor[0], custom_cursor[1], custom_cursor[2])
             else:
                 cursor_get = getattr(
                     __import__("glfw", fromlist=[f"{name}_CURSOR"]), f"{name}_CURSOR"
@@ -1054,9 +1079,7 @@ class SkWindowBase(SkEventHanding, SkMisc):
 
     cursor = wm_cursor
 
-    def default_cursor(
-        self, cursor_name: str | None = None
-    ) -> typing.Union[str, "SkWindowBase"]:
+    def default_cursor(self, cursor_name: str | None = None) -> typing.Union[str, "SkWindowBase"]:
         """Set the default cursor style of the window.
 
         cursor_name:
@@ -1071,9 +1094,7 @@ class SkWindowBase(SkEventHanding, SkMisc):
         self.configure(cursor=cursor_name)
         return self
 
-    def wm_visible(
-        self, is_visible: bool | None = None
-    ) -> typing.Union[bool, "SkWindowBase"]:
+    def wm_visible(self, is_visible: bool | None = None) -> typing.Union[bool, "SkWindowBase"]:
         """Get or set the visibility of the window.
 
         is_visible:
@@ -1106,7 +1127,7 @@ class SkWindowBase(SkEventHanding, SkMisc):
         if hasattr(self, "update_layout"):
             self.update_layout()  # 添加初始布局更新
         glfw.show_window(self.the_window)
-        self.update()  # 添加初始绘制触发
+        self.update(True)  # 添加初始绘制触发
         return self
 
     show = wm_show
@@ -1160,14 +1181,24 @@ class SkWindowBase(SkEventHanding, SkMisc):
 
     restore = wm_restore
 
-    def destroy(self) -> None:
+    def wm_destroy(self) -> None:
         """Destroy the window.
 
         :return: None
         """
         # self._event_init = False
         # print(self.id)
-        self.can_be_close(True)
+        self.application.destroy_window(self)
+        glfw.destroy_window(self.the_window)
+
+        self.alive = False
+        self.draw_func = None
+        self.the_window = None  # Clear the reference
+
+        for child in self.children:
+            child.destroy()
+
+    destroy = wm_destroy
 
     def wm_title(self, text: str | None = None) -> typing.Union[str, "SkWindowBase"]:
         """Get or set the window title.
@@ -1191,9 +1222,7 @@ class SkWindowBase(SkEventHanding, SkMisc):
 
     title = wm_title
 
-    def resize(
-        self, width: int | None = None, height: int | None = None
-    ) -> "SkWindowBase":
+    def resize(self, width: int | None = None, height: int | None = None) -> "SkWindowBase":
         """Resize the window.
 
         :param width: Width
@@ -1211,9 +1240,7 @@ class SkWindowBase(SkEventHanding, SkMisc):
         from glfw import set_window_size
 
         set_window_size(self.the_window, round(width), round(height))
-        self.event_trigger(
-            "resize", SkEvent(event_type="resize", width=width, height=height)
-        )
+        self.trigger("resize", SkEvent(event_type="resize", width=width, height=height))
 
         return self
 
@@ -1237,7 +1264,7 @@ class SkWindowBase(SkEventHanding, SkMisc):
         from glfw import set_window_pos
 
         set_window_pos(self.the_window, round(x), round(y))
-        self.event_trigger("move", SkEvent(event_type="move", rootx=x, rooty=y))
+        self.trigger("move", SkEvent(event_type="move", rootx=x, rooty=y))
 
         return self
 
@@ -1291,7 +1318,7 @@ class SkWindowBase(SkEventHanding, SkMisc):
                 print(f"[ERROR] Failed to set opacity: {e}")
 
         self.attributes.update(kwargs)
-        self.event_trigger("configure", SkEvent(event_type="configure", widget=self))
+        self.trigger("configure", SkEvent(event_type="configure", widget=self))
         return self
 
     config = configure = set_attribute
@@ -1348,9 +1375,7 @@ class SkWindowBase(SkEventHanding, SkMisc):
             self.dpi_scale = 1.0
 
         # 触发DPI变化事件
-        self.event_trigger(
-            "dpi_change", SkEvent(event_type="dpi_change", dpi_scale=self.dpi_scale)
-        )
+        self.trigger("dpi_change", SkEvent(event_type="dpi_change", dpi_scale=self.dpi_scale))
 
     def _on_dpi_change(self, window, xscale, yscale) -> None:
         """Handle DPI change event
@@ -1363,11 +1388,9 @@ class SkWindowBase(SkEventHanding, SkMisc):
         self.dpi_scale = (xscale + yscale) / 2.0
 
         # 触发DPI变化事件
-        self.event_trigger(
+        self.trigger(
             "dpi_change",
-            SkEvent(
-                event_type="dpi_change", dpi_scale=self.dpi_scale, glfw_window=window
-            ),
+            SkEvent(event_type="dpi_change", dpi_scale=self.dpi_scale, glfw_window=window),
         )
 
         # 更新窗口物理尺寸
@@ -1387,9 +1410,6 @@ class SkWindowBase(SkEventHanding, SkMisc):
 
     # 添加设置DPI缩放因子的方法
     def set_dpi_scale(self, scale: float) -> "SkWindowBase":
-
-        self.update()
-
         """Set DPI scale factor
 
         :param scale: DPI scale factor
@@ -1403,10 +1423,8 @@ class SkWindowBase(SkEventHanding, SkMisc):
         self.physical_height = int(self.height * scale)
 
         # 触发DPI变化事件
-        self.event_trigger(
-            "dpi_change", SkEvent(event_type="dpi_change", dpi_scale=scale)
-        )
+        self.trigger("dpi_change", SkEvent(event_type="dpi_change", dpi_scale=scale))
 
-        return self
+        self.update(True)
 
     # endregion
