@@ -8,8 +8,6 @@ from .frame import SkFrame
 class SkButton(SkFrame):
     """Button without Label or Icon.
 
-    **Will be re-written in the future.**
-
     :param args: Passed to SkVisual
     :param text: Button text
     :param size: Default size
@@ -24,11 +22,11 @@ class SkButton(SkFrame):
         parent: SkContainer,
         *,
         style: str = "SkButton",
-        cursor: typing.Union[str, None] = "hand",
+        cursor: typing.Union[str, None] = "arrow",
         command: typing.Union[typing.Callable, None] = None,
         **kwargs,
     ) -> None:
-        super().__init__(parent, style=style, **kwargs)
+        super().__init__(parent, style=style, is_combo_widget=True, **kwargs)
 
         self.attributes["cursor"] = cursor
         self.attributes["command"] = command
@@ -40,29 +38,29 @@ class SkButton(SkFrame):
 
     def _click(self, event) -> None:
         """
-        Check click event (not pressed)
+        Check click event (not press)
 
         :return: None
         """
         if self.button != 1:
             if self.is_mouse_floating:
 
-                self.event_trigger("click", event)
+                self.trigger("click", event)
                 self.invoke()
                 time = self.time()
 
                 if self.click_time + self.cget("double_click_interval") > time:
-                    self.event_trigger("double_click", event)
+                    self.trigger("double_click", event)
                     self.click_time = 0
                 else:
                     self.click_time = time
 
     def invoke(self) -> None:
-        """【触发按钮的点击事件】"""
-        if self.cget("command") and self.cget("disabled") is False:
+        """Trigger button click event"""
+        if self.cget("command") and not self.cget("disabled"):
             self.cget("command")()
 
-    def draw_widget(self, canvas, rect, style_selector: str | None = None) -> None:
+    def draw_widget(self, canvas, rect, style_selector: str | None = None) -> str:
         """Draw button
 
         :param canvas: skia.Surface to draw on
@@ -74,38 +72,31 @@ class SkButton(SkFrame):
         if style_selector is None:
             if not self.cget("disabled"):
                 if self.is_mouse_floating:
-                    if self.is_mouse_pressed:
-                        style_selector = f"{self.style}:pressed"
+                    if self.is_mouse_press:
+                        style_selector = f"{self.style_name}:press"
                     else:
-                        style_selector = f"{self.style}:hover"
+                        style_selector = f"{self.style_name}:hover"
                 else:
-                    if "focus" in self.styles[self.style]:
-                        if self.is_focus:
-                            style_selector = f"{self.style}:focus"
-                        else:
-                            style_selector = self.style
+                    if self.is_focus and self.focusable:
+                        style_selector = f"{self.style_name}:focus"
                     else:
-                        style_selector = self.style
+                        style_selector = self.style_name
             else:
-                style_selector = f"{self.style}:disabled"
+                style_selector = f"{self.style_name}:disabled"
 
-        style = self.theme.get_style(style_selector)
-        bg_shader = self._style("bg_shader", None, style)
-        # bd_shadow = self.theme.get_style_attr(style_selector, "bd_shadow")
-        bd_shadow = self._style("bd_shadow", None, style)
-        bd_shader = self._style("bd_shader", None, style)
-        width = self.theme.get_style_attr(style_selector, "width")
-        # self._style("width", 0, style)
-        # bd = self.theme.get_style_attr(style_selector, "bd")
-        bd = self._style("bd", None, style)
-        # bg = self.theme.get_style_attr(style_selector, "bg")
-        bg = self._style("bg", None, style)
+        bg_shader = self._style2(self.theme, style_selector, "bg_shader")
+        bd_shader = self._style2(self.theme, style_selector, "bd_shader")
+        bd_shadow = self._style2(self.theme, style_selector, "bd_shadow")
+        width = self._style2(self.theme, style_selector, "width", 0)
+        bd = self._style2(self.theme, style_selector, "bd")
+        bg = self._style2(self.theme, style_selector, "bg")
+        radius = self._style2(self.theme, style_selector, "radius", 0)
 
         # Draw the button border
         self._draw_rect(
             canvas,
             rect,
-            radius=self.theme.get_style_attr(self.style, "radius"),
+            radius=radius,
             bg=bg,
             width=width,
             bd=bd,
@@ -114,11 +105,4 @@ class SkButton(SkFrame):
             bg_shader=bg_shader,
         )
 
-        """rest_style = self.theme.get_style(self.style)
-        hover_style = self.theme.get_style(self.style + ":hover")
-        if "bg" in hover_style:
-            bg = hover_style["bg"]
-        else:
-            bg = rest_style["bg"]"""
-
-        return style
+        return style_selector
