@@ -1,3 +1,5 @@
+from __future__ import annotations as _
+
 import array
 import typing
 
@@ -5,6 +7,11 @@ import skia
 
 from ..const import Orient
 from ..event import SkEvent
+from ..misc import SkMisc
+
+if typing.TYPE_CHECKING:
+    from .. import SkEventHandling
+    from . import SkWidget
 
 
 class SkLayoutError(TypeError):
@@ -60,14 +67,19 @@ class SkContainer:
     def __exit__(self, exc_type, exc_val, exc_tb):
         self._handle_layout()
         # 触发更新事件
-        self.event_trigger("update", SkEvent(event_type="update"))
+        if isinstance(self, SkEventHandling):
+            self.trigger("update", SkEvent(widget=self, event_type="update"))
+            self.update()
 
-    def __init__(self, allowed_out_of_bounds: bool = False):
+    def __init__(self, allowed_out_of_bounds: bool = False, is_combo_widget: bool = False):
 
         # self.parent = None
-        self.children = []  # Children
-
-        from .widget import SkWidget
+        self.is_combo_widget: bool = (
+            is_combo_widget  # if True, then this container is a combo widget and help parent scroll
+        )
+        self.need_redraw: bool
+        self.is_mouse_floating: bool
+        self.children: list[SkWidget] = []  # Children
 
         self.draw_list: list[list[SkWidget]] = [
             [],  # Layout layer [SkWidget1, SkWidget2, ...]
@@ -77,27 +89,26 @@ class SkContainer:
         self.layout_names = [None, None, None]
 
         # 【内部组件统计总占大小】
-        self.content_width = 0
-        self.content_height = 0
+        self.content_width: int | float = 0
+        self.content_height: int | float = 0
 
         # 【内部组件偏移，用于实现容器内部的滚动】
-        self._x_offset = 0
-        self._y_offset = 0
+        self._x_offset: int | float = 0
+        self._y_offset: int | float = 0
         self.allowed_scrolled: bool = False
         self.scroll_speed: float | int = 18  # 滚动距离：滚动量x滚动速度
 
         self._grid_lists = []  # [ [row1, ], [] ]
         self._box_direction: Orient | None = None  # h(horizontal) or v(vertical)
         self._flow_row = 0
-        self.allowed_out_of_bounds = (
-            allowed_out_of_bounds  # 【是否允许组件超出容器范围】
-        )
+        self.allowed_out_of_bounds = allowed_out_of_bounds  # 【是否允许组件超出容器范围】
 
         # Events
         self.bind("resize", lambda _: self.update_layout())
 
     # endregion
 
+    # region Scroll
     def bind_scroll_event(self):
         # 【容器绑定滚动事件，鼠标滚轮滚动可以滚动容器】
         self.allowed_scrolled = True
@@ -106,17 +117,17 @@ class SkContainer:
     def scroll_event(self, event: SkEvent) -> None:
         """【处理滚动事件】"""
         if self.allowed_scrolled:
+            # typing.cast("SkWidget", self)
             if self.is_mouse_floating:
-                self.scroll(event.x_offset * 18, event.y_offset * 18)
+                self.scroll(event["x_offset"] * 18, event["y_offset"] * 18)
                 return
 
             for child in self.children:
-                if (
-                    child.is_mouse_floating
-                    and child.help_parent_scroll
-                    and child.parent == self
-                ):
-                    self.scroll(event.x_offset * 18, event.y_offset * 18)
+                if child.is_mouse_floating and child.help_parent_scroll and child.parent == self:
+                    if isinstance(child, SkContainer):
+                        if not child.is_combo_widget:
+                            break
+                    self.scroll(event["x_offset"] * 18, event["y_offset"] * 18)
                     return
 
     def update_scroll(self) -> None:
@@ -147,8 +158,13 @@ class SkContainer:
         self.x_offset = min(self.x_offset + x_offset, 0)
         # 防止容器超出上边界
         self.y_offset = min(self.y_offset + y_offset, 0)
+        self.update(redraw=True)
+        self.trigger("scrolled", SkEvent(self, "scrolled"))
+
+    # endregion
 
     # region add_child 添加子元素
+
     def add_child(self, child):
         """Add child widget to window.
 
@@ -172,25 +188,41 @@ class SkContainer:
 
     def grid_map(self):
         # Grid Map
-        from .widget import SkWidget
+        # [ [widget1, widget2, ...], [widget3, widget4, ...], ... ]
+        # 【根据网格布局配置，将子元素组织成网格地图】
 
         grid_map: list[list[SkWidget | None]] = []
         children: list[SkWidget] = self.draw_list[0]
 
         for child in children:
+            if child is None:
+                continue
             child_config = child.layout_config["grid"]
             row, col = child_config["row"], child_config["column"]
 
-            if col > len(grid_map) - 1:
-                while col > len(grid_map) - 1:
-                    grid_map.append([])
-            if row > len(grid_map[col]) - 1:
-                while row > len(grid_map[col]) - 1:
-                    grid_map[col].append(None)
-            grid_map[col][row] = child
+            if row < 0 or col < 0:
+                continue
+
+            # 确保有足够的行
+            while len(grid_map) <= row:
+                grid_map.append([])
+
+            # 确保当前行有足够的列
+            current_row = grid_map[row]
+            while len(current_row) <= col:
+                current_row.append(None)
+
+            # 放置组件
+            grid_map[row][col] = child
+
         return grid_map
 
-    def add_layout_child(self, child):
+    def add_layer_child(self, layer, child):
+        self.draw_list[layer].append(child)
+
+        self.update_layout()
+
+    def add_layer1_child(self, child):
         """Add layout child widget to window.
 
         :arg child: SkWidget
@@ -209,31 +241,25 @@ class SkContainer:
 
             if self._box_direction == Orient.V:
                 if direction == Orient.H:
-                    raise ValueError(
-                        "Box layout can only be used with vertical direction."
-                    )
+                    raise ValueError("Box layout can only be used with vertical direction.")
             elif self._box_direction == Orient.H:
                 if direction == Orient.V:
-                    raise ValueError(
-                        "Box layout can only be used with horizontal direction."
-                    )
+                    raise ValueError("Box layout can only be used with horizontal direction.")
             else:
                 self._box_direction = direction
 
-        self.draw_list[0].append(child)
-        self.update_layout()
+        self.add_layer_child(0, child)
 
-    def add_floating_child(self, child):
+    def add_layer2_child(self, child):
         """Add floating child widget to window.
 
         :arg child: SkWidget
         :return: None
         """
 
-        self.draw_list[1].append(child)
-        self.update_layout()
+        self.add_layer_child(1, child)
 
-    def add_fixed_child(self, child):
+    def add_layer3_child(self, child):
         """Add fixed child widget to window.
 
         Example:
@@ -244,8 +270,7 @@ class SkContainer:
         :arg child: SkWidget
         :return: None
         """
-        self.draw_list[2].append(child)
-        self.update_layout()
+        self.add_layer_child(2, child)
 
     # endregion
 
@@ -257,11 +282,10 @@ class SkContainer:
         :param canvas: The canvas to draw on
         :return: None
         """
-        from ..widgets.widget import SkWidget
-        from .window import SkWindow
 
-        if not isinstance(self, SkWindow):
-            if isinstance(self, SkWidget):
+        if "SkWindow" not in SkMisc.sk_get_type(self):
+            if "SkWidget" in SkMisc.sk_get_type(self):
+                typing.cast("SkWidget", self)
                 x = self.canvas_x
                 y = self.canvas_y
             else:
@@ -297,7 +321,10 @@ class SkContainer:
         self.update_scroll()
         self._handle_layout()
         for widget in self.children:
-            widget.event_trigger("resize", SkEvent(event_type="resize"))
+            widget.trigger("resize", SkEvent(widget=self, event_type="resize"))
+
+    def reset_content_size(self):
+        self.content_width, self.content_height = 0, 0
 
     def record_content_size(self, child, padx=0, pady=0):
         self.content_width = max(child.x + child.dwidth + padx, self.content_width)
@@ -339,46 +366,87 @@ class SkContainer:
         pass
 
     def _handle_grid(self):
-        from .widget import SkWidget
+        self.reset_content_size()
 
         # Grid
-        col_heights: list[int | float] = []
-        row_widths: list[int | float] = []
-        # children: list[SkWidget] = self.draw_list[0]
+        row_heights: list[int | float] = []
+        col_widths: list[int | float] = []
         grid_map = self.grid_map()
 
-        for col, cols in enumerate(grid_map):
-
-            for row, widget in enumerate(cols):
+        # 第一步：计算行列尺寸（包含ipadx/ipady）
+        for row, rows in enumerate(grid_map):
+            for col, widget in enumerate(rows):
+                if widget is None:
+                    continue
                 child_config = widget.layout_config["grid"]
 
-                left, top, right, bottom = self.unpack_padding(
+                # 解包外部padding
+                pad_left, pad_top, pad_right, pad_bottom = self.unpack_padding(
                     child_config["padx"],
                     child_config["pady"],
                 )
-                if len(row_widths) <= row:
-                    row_widths.append(0)
-                row_widths[row] = max(row_widths[row], widget.dwidth)
-                if len(col_heights) <= col:
-                    col_heights.append(0)
-                col_heights[col] = max(col_heights[col], widget.dheight + left + bottom)
-            # print(row_widths, col_heights)
-            row_left = 0
 
-            for row, widget in enumerate(cols):
+                # 解包内部padding（形式相同）
+                ipad_left, ipad_top, ipad_right, ipad_bottom = self.unpack_padding(
+                    child_config["ipadx"],
+                    child_config["ipady"],
+                )
+
+                if len(col_widths) <= col:
+                    col_widths.append(0)
+                # 总宽度 = 内容宽度 + 内部padding
+                total_width = widget.dwidth + ipad_left + ipad_right + pad_left + pad_right
+                col_widths[col] = max(col_widths[col], total_width)
+
+                if len(row_heights) <= row:
+                    row_heights.append(0)
+                # 总高度 = 内容高度 + 内部padding
+                total_height = widget.dheight + ipad_top + ipad_bottom + pad_top + pad_bottom
+                row_heights[row] = max(row_heights[row], total_height)
+
+        self.content_height = total_row_height = sum(row_heights)
+        self.content_width = total_col_width = sum(col_widths)
+
+        # 第二步：定位widgets（包含ipadx/ipady）
+        for row, rows in enumerate(grid_map):
+            row_top = sum(row_heights[:row])
+            col_left = 0
+
+            for col, widget in enumerate(rows):
+                if widget is None:
+                    continue
                 child_config = widget.layout_config["grid"]
-                # print(child_config)
-                col_top = sum(col_heights[:col])
-                left, top, right, bottom = self.unpack_padding(
+
+                # 解包外部padding
+                pad_left, pad_top, pad_right, pad_bottom = self.unpack_padding(
                     child_config["padx"],
                     child_config["pady"],
                 )
+
+                # 解包内部padding
+                ipad_left, ipad_top, ipad_right, ipad_bottom = self.unpack_padding(
+                    child_config["ipadx"],
+                    child_config["ipady"],
+                )
+
+                col_width = sum(col_widths[col : col + child_config["columnspan"]])
+                row_height = sum(row_heights[row : row + child_config["rowspan"]])
+
+                # widget实际尺寸 = 单元格尺寸 - 外部padding - 内部padding
                 widget.width, widget.height = (
-                    row_widths[row],
-                    col_heights[col] - top - bottom,
+                    col_width - pad_left - pad_right,
+                    row_height - pad_top - pad_bottom,
                 )
-                widget.x, widget.y = row_left + left, col_top + top
-                row_left = widget.x + widget.width + right
+
+                # widget位置 = 单元格位置 + 外部padding + 内部padding
+                widget.x, widget.y = (
+                    col_left + pad_left,
+                    row_top + pad_top,
+                )
+                widget.x += self.x_offset
+                widget.y += self.y_offset
+
+                col_left = widget.x + widget.width + ipad_right
 
     def _handle_box(self) -> None:
         """Process box layout.
@@ -387,8 +455,7 @@ class SkContainer:
         """
 
         # TODO 做好ipadx、ipady的处理
-
-        from .widget import SkWidget
+        self.reset_content_size()
 
         width = self.width  # container width
         height = self.height  # container height
@@ -596,4 +663,9 @@ class SkContainer:
         self._y_offset = value
         self.update_layout(None)
 
+    def update(self):
+        self.update_layout()
+        for child in self.children:
+            child.update()
+
     # endregion
