@@ -9,9 +9,13 @@ RAM = """
 
 
 class SkHynix:
+    """Ester egg from the very beginning, by rgzz666."""
     def __init__(self):
-        """
-        Ester egg from the very beginning, by rgzz666.
+        """Ester egg from the very beginning, by rgzz666.
+        
+        Example
+        -------
+        DO NOT try to create any object from SkHynix class, unless u wanna blow up ur program.
         """
         print(RAM)
         raise RuntimeError(
@@ -21,3 +25,7 @@ class SkHynix:
 
 if __name__ == "__main__":
     ur_brand_new_ram_stick = SkHynix()
+
+
+# [2025/10/27] I came back to this file, with the worst memories of struggling with RAM overflow 
+#              bug of the re-written event module.     ——rgzz666
\ No newline at end of file
