@@ -37,6 +37,7 @@ class SkLineInput(SkWidget):
         placeholder: str | None = None,
         readonly: bool = False,
         cursor="ibeam",
+        style_name="SkEntry",
         show: str | None = None,
         **kwargs,
     ) -> None:
@@ -47,7 +48,7 @@ class SkLineInput(SkWidget):
         :param placeholder: 占位符
         :param cursor: 光标样式
         """
-        super().__init__(parent=parent, cursor=cursor, **kwargs)
+        super().__init__(parent=parent, cursor=cursor, style_name=style_name, **kwargs)
 
         # Attributes
         self.attributes["readonly"] = readonly
@@ -71,17 +72,19 @@ class SkLineInput(SkWidget):
         self.undo_stack = []
         self.redo_stack = []
         self.max_undo_stack = 30
+        self.help_parent_scroll = True
 
         # Event binding
         self.bind("double_click", self._double_click)
         self.bind("focus_gain", self._focus_gain)
         self.bind("char", self._char)
-        self.bind("key_pressed", self._key)
-        self.bind("key_repeated", self._key)
-        self.bind("mouse_pressed", self._pressed)
+        self.bind("key_press", self._key)
+        self.bind("key_repeat", self._key)
+        self.bind("mouse_press[b1]", self._press)
         self.window.bind("mouse_motion", self._motion)
         self.bind("mouse_motion", self._motion)
         self.bind("scroll", self._scroll)
+        # self.window
 
     # endregion
 
@@ -108,9 +111,9 @@ class SkLineInput(SkWidget):
         :return: None
         """
         return
-        if event.y_offset > 0 or event.x_offset > 0:
+        if event["y_offset"] > 0 or event["x_offset"] > 0:
             self.cursor_right()
-        elif event.y_offset < 0 or event.x_offset < 0:
+        elif event["y_offset"] < 0 or event["x_offset"] < 0:
             self.cursor_left()
         self.cursor_visible = True
 
@@ -123,23 +126,24 @@ class SkLineInput(SkWidget):
         self.cursor_visible = True
 
     def _motion(self, event: SkEvent) -> None:
-        """Record the `end_index` when the text is pressed and moved.
+        """Record the `end_index` when the text is press and moved.
         【当文本被按住并移动时，记录end_index】
         :param event: SkEvent
         """
         # 【只有在左键按下时，才记录end_index】
         if self.button == 0:
-            if self.is_mouse_pressed:
-                self.end_index = self.index(event.x)
+            if self.is_mouse_press:
+                self.end_index = self.index(event["x"])
+                self.update(True)
 
-    def _pressed(self, event: SkEvent) -> None:
-        """Record the `start_index` and `end_index` when the text is pressed.
+    def _press(self, event: SkEvent) -> None:
+        """Record the `start_index` and `end_index` when the text is press.
         【当文本被按住时，记录`start_index`与`end_index`。】
         """
         # 【只有在左键按下时，才记录start_index】
-        if event.button == 0:
-            self.cursor_visible = True
-            self.start_index = self.end_index = self.index(event.x)
+        self.cursor_visible = True
+        self.start_index = self.end_index = self.index(event["x"])
+        self.update(True)
 
     def _char(self, event: SkEvent):
         """Triggered when input text is entered.
@@ -155,15 +159,16 @@ class SkLineInput(SkWidget):
 
         # 当文本未被选中时，正常在文本后添加文本，并更新光标索引
         if not self.is_selected():
-            self.set(text[:cursor_index] + event.char + text[cursor_index:])
+            self.set(text[:cursor_index] + event["char"] + text[cursor_index:])
             self.cursor_right()
         # 当文本被选中时，将选中文本替代为输入的文本
         else:
             start, end = self.sort_select()
-            self.set(text[:start] + event.char + text[end:])
+            self.set(text[:start] + event["char"] + text[end:])
             self.start_index = self.end_index = self._cursor_index = len(
-                text[:start] + event.char
+                text[:start] + event["char"]
             )
+        self.update(True)
 
     def _key(self, event: SkEvent):
         """Key event 按键事件触发
@@ -173,7 +178,8 @@ class SkLineInput(SkWidget):
         """
 
         # 快捷键
-        match event.key:
+        mods = event["mods"]
+        match event["key"]:
             # Backspace 删除光标前面文本
             case glfw.KEY_BACKSPACE:
                 """Delete the text before the cursor"""
@@ -185,21 +191,21 @@ class SkLineInput(SkWidget):
             # Ctrl + V 粘贴
             case glfw.KEY_V:
                 """Paste Text"""
-                if event.mods == "control":
+                if mods == "control":
                     self.cursor_paste()
             # Ctrl + C 复制
             case glfw.KEY_C:
-                if event.mods == "control":
+                if mods == "control":
                     self.cursor_copy()
             # Ctrl + A 全选
             case glfw.KEY_A:
                 """Select All"""
-                if event.mods == "control":
+                if mods == "control":
                     self.cursor_select_all()
             # Ctrl + X 剪切
             case glfw.KEY_X:
                 """Cut Text"""
-                if event.mods == "control":
+                if mods == "control":
                     self.cursor_cut()
             # Home ↑ 光标移至最左
             case glfw.KEY_HOME | glfw.KEY_UP:
@@ -219,9 +225,9 @@ class SkLineInput(SkWidget):
                 self.cursor_right()
             case glfw.KEY_Z:
                 """Redo"""
-                if event.mods == "control":
+                if mods == "control":
                     self.undo()
-                elif event.mods == "control+shift":
+                elif mods == "control+shift":
                     self.redo()
 
     def get(self) -> str:
@@ -243,6 +249,8 @@ class SkLineInput(SkWidget):
             self.attributes["textvariable"].set(text)
         else:
             self.attributes["text"] = text
+        self.update(True)
+
         return self
 
     def index(self, mouse_x: int) -> int:
@@ -278,9 +286,7 @@ class SkLineInput(SkWidget):
             self.visible_start_index = self.cursor_index() - 2
             if self.visible_start_index < 0:
                 self.visible_start_index = 0
-        if self.visible_start_index > len(self.get()) or self.cursor_index() > len(
-            self.get()
-        ):
+        if self.visible_start_index > len(self.get()) or self.cursor_index() > len(self.get()):
             self.cursor_index(len(self.get()))
             self.visible_start_index = self.cursor_index()
 
@@ -309,6 +315,7 @@ class SkLineInput(SkWidget):
             # 更新光标位置到文本末尾
             self.cursor_end()
             self.check()
+            self.update(True)
 
     def undo(self):
         """Undo the last operation【撤销上一个操作】"""
@@ -326,6 +333,7 @@ class SkLineInput(SkWidget):
             # 更新光标位置到文本末尾
             self.cursor_end()
             self.check()
+            self.update(True)
 
     def cursor_index(self, index: int | None = None) -> Self | int:
         """Set cursor index
@@ -333,6 +341,7 @@ class SkLineInput(SkWidget):
         """
         if index and isinstance(index, int):
             self._cursor_index = index
+            self.update(True)
         else:
             return self._cursor_index
         return self
@@ -362,8 +371,7 @@ class SkLineInput(SkWidget):
             # 【光标向左移动时，若文本可显的初始索引大于等于光标索引，且文本可显的初始索引不为0】
             while (
                 self.visible_start_index
-                >= self._cursor_index
-                - 1  # 【当光标向左移动时，如果光标在可显文本的第二位】
+                >= self._cursor_index - 1  # 【当光标向左移动时，如果光标在可显文本的第二位】
                 and self.visible_start_index != 0
             ):
                 self.visible_start_index -= move
@@ -372,6 +380,8 @@ class SkLineInput(SkWidget):
                 if self.is_selected():
                     self.start_index = self.end_index = 0
         self.cursor_visible = True
+        self.update(True)
+
         return self
 
     def cursor_right(self, move: int = 1, cancel_selected: bool = True) -> Self:
@@ -414,6 +424,8 @@ class SkLineInput(SkWidget):
                 if self.is_selected():
                     self.start_index = self.end_index = long
         self.cursor_visible = True
+        self.update(True)
+
         return self
 
     def delete_selected(self) -> Self:
@@ -424,11 +436,11 @@ class SkLineInput(SkWidget):
             return self
         if self.is_selected():
             start, end = self.sort_select()
-            self.start_index = self.end_index = self._cursor_index = len(
-                self.show_text[:start]
-            )
+            self.start_index = self.end_index = self._cursor_index = len(self.show_text[:start])
             self.set(self.get()[:start] + self.get()[end:])
             self.check()
+        self.update(True)
+
         return self
 
     def cursor_backspace(self) -> Self:
@@ -440,14 +452,13 @@ class SkLineInput(SkWidget):
         self.record_state()
         if not self.is_selected():
             if self.cursor_index() > 0:
-                self.set(
-                    self.get()[: self.cursor_index() - 1]
-                    + self.get()[self.cursor_index() :]
-                )
+                self.set(self.get()[: self.cursor_index() - 1] + self.get()[self.cursor_index() :])
                 self.cursor_left()
         else:
             self.delete_selected()
         self.cursor_visible = True
+        self.update(True)
+
         return self
 
     def cursor_delete(self) -> Self:
@@ -473,6 +484,8 @@ class SkLineInput(SkWidget):
             self.record_state()
             self.delete_selected()
         self.cursor_visible = True
+        self.update(True)
+
         return self
 
     def cursor_home(self) -> Self:
@@ -482,6 +495,8 @@ class SkLineInput(SkWidget):
         self._cursor_index = 0
         self.visible_start_index = 0
         self.cursor_visible = True
+        self.update(True)
+
         return self
 
     def cursor_end(self) -> Self:
@@ -491,14 +506,14 @@ class SkLineInput(SkWidget):
         self._cursor_index = len(self.get())
         while (
             self.measure_text(
-                self.show_text[
-                    self.visible_start_index : self.cursor_index()
-                ]  # 光标左边的可显文本
+                self.show_text[self.visible_start_index : self.cursor_index()]  # 光标左边的可显文本
             )
             >= self._rect.width()
         ):
             self.visible_start_index += 1
         self.cursor_visible = True
+        self.update(True)
+
         return self
 
     def cursor_paste(self):
@@ -516,9 +531,7 @@ class SkLineInput(SkWidget):
 
             # 【如没有选中文本，则在光标后粘贴文本】
             if not self.is_selected():
-                self.set(
-                    text[: self._cursor_index] + clipboard + text[self._cursor_index :]
-                )
+                self.set(text[: self._cursor_index] + clipboard + text[self._cursor_index :])
                 self.cursor_right(len(clipboard))
             # 【如选中文本，则粘贴并覆盖选中文本】
             else:
@@ -528,6 +541,7 @@ class SkLineInput(SkWidget):
                 index = start + len(clipboard)
                 self.cursor_index(index)
                 self.start_index = self.end_index = index
+            self.update(True)
 
     def cursor_copy(self):
         """Copy the selected text
@@ -547,6 +561,7 @@ class SkLineInput(SkWidget):
             if self.attributes["readonly"]:
                 return
             self.cursor_backspace()
+            self.update(True)
 
     def sort_select(self):
         return sorted([self.start_index, self.end_index])
@@ -554,6 +569,7 @@ class SkLineInput(SkWidget):
     def cursor_select(self, start: int, end: int):
         self.start_index = start
         self.end_index = self._cursor_index = end
+        self.update(True)
 
     def cursor_select_all(self):
         """Select all text
@@ -567,57 +583,47 @@ class SkLineInput(SkWidget):
 
     def blink(self, event=None):
         self.cursor_visible = not self.cursor_visible
+        self.need_redraw = True
         # 【仅当输入框获得焦点时光标闪烁】
         # 【如果一同执行，会导致只有最后一个输入框的光标闪烁】
         if self.is_focus:
-            self.after(self.cget("blink_interval"), self.blink)
+            blink_interval = self.cget("blink_interval")
+            self.bind(f"delay[{blink_interval}]", self.blink)
 
     def draw_widget(self, canvas: skia.Surface, rect: skia.Rect) -> None:
         """Draw the text input
         【绘制输入框（不含边框）】
         """
-        if self.is_mouse_floating:
-            if self.is_focus:
-                style_name = "SkEntry:focus"
+        if not self.cget("disabled"):
+            if self.is_mouse_floating:
+                if self.is_focus:
+                    style_selector = f"{self.style_name}:focus"
+                else:
+                    style_selector = f"{self.style_name}:hover"
+            elif self.is_focus:
+                style_selector = f"{self.style_name}:focus"
             else:
-                style_name = "SkEntry:hover"
-        elif self.is_focus:
-            style_name = "SkEntry:focus"
+                style_selector = self.style_name
         else:
-            style_name = "SkEntry"
+            style_selector = f"{self.style_name}:disabled"
 
-        style = self.theme.get_style(style_name)
-        radius = self.theme.get_style_attr("SkEntry", "radius")
-
-        if "selected_bg" in style:
-            selected_bg = style["selected_bg"]
-        else:
-            selected_bg = skia.ColorBLUE
-        if "selected_fg" in style:
-            selected_fg = style["selected_fg"]
-        else:
-            selected_fg = skia.ColorWHITE
-        if "cursor" in style:
-            cursor = style["cursor"]
-        else:
-            cursor = None
-        if "placeholder" in style:
-            placeholder = style["placeholder"]
-        else:
-            placeholder = None
-        if "selected_radius" in style:
-            selected_radius = style["selected_radius"]
-        else:
-            selected_radius = True
+        radius = self._style2(self.theme, style_selector, "radius", 0)
+        fg = self._style2(self.theme, style_selector, "fg")
+        selected_bg = self._style2(self.theme, style_selector, "selected_bg")
+        selected_fg = self._style2(self.theme, style_selector, "selected_fg")
+        cursor = self._style2(self.theme, style_selector, "cursor")
+        placeholder = self._style2(self.theme, style_selector, "placeholder")
+        selected_radius = self._style2(self.theme, style_selector, "selected_radius", True)
         if isinstance(selected_radius, bool):
             if selected_radius:
                 selected_radius = radius
             else:
                 selected_radius = 0
+
         self._draw_text_input(
             canvas,
             rect,
-            fg=style["fg"],
+            fg=fg,
             placeholder=placeholder,
             selected_bg=selected_bg,
             selected_fg=selected_fg,
@@ -659,9 +665,7 @@ class SkLineInput(SkWidget):
             placeholder = fg
 
         if cursor:
-            cursor = skcolor_to_color(
-                style_to_color(cursor, self.theme)
-            )  # 设置光标颜色
+            cursor = skcolor_to_color(style_to_color(cursor, self.theme))  # 设置光标颜色
         else:
             cursor = fg
 
@@ -749,9 +753,7 @@ class SkLineInput(SkWidget):
             if self.cursor_visible:
                 # 【计算出的光标位置】
                 cursor_x = self._rect.left() + self.measure_text(
-                    text[
-                        self.visible_start_index : self.cursor_index()
-                    ]  # 光标左边的可显文本
+                    text[self.visible_start_index : self.cursor_index()]  # 光标左边的可显文本
                 )
                 canvas.drawLine(
                     x0=cursor_x,
