@@ -37,12 +37,28 @@ class SkListItem(SkTextButton):
         self, canvas: skia.Canvas, rect: skia.Rect, style_selector: str | None = None
     ) -> None:
         if self.selected:
-            style_selector = f"{self.style}:selected"
+            style_selector = f"{self.style_name}:selected"
         else:
             if self.is_mouse_floating:
-                if self.is_mouse_pressed:
-                    style_selector = f"{self.style}:pressed"
+                if self.is_mouse_press:
+                    style_selector = f"{self.style_name}:press"
                 else:
-                    style_selector = f"{self.style}:hover"
-
+                    style_selector = f"{self.style_name}:hover"
+        style = self.theme.select(style_selector)
         super().draw_widget(canvas, rect, style_selector)
+
+        if self.selected:
+            if "leftline" in style and "leftline_width" in style:
+                leftline = self._style("leftline", None, style)
+                leftline_width = self._style("leftline_width", 0, style)
+                leftline_ipadx = self._style("leftline_ipadx", 2, style)
+                leftline_ipady = self.unpack_pady(self._style("leftline_ipady", (5, 5), style))
+                self._draw_line(
+                    canvas,
+                    rect.left() + leftline_ipadx,
+                    rect.top() + leftline_ipady[0],
+                    rect.left() + leftline_ipadx,
+                    rect.bottom() - leftline_ipady[1],
+                    width=leftline_width,
+                    fg=leftline,
+                )
