@@ -10,11 +10,11 @@ class SkPopup(SkCard):
 
         self.focusable = True
 
-        self.event_generate("hide")
         self.bind("hide", self._hide)
 
         # 【来检查是否需要关闭改弹出菜单】
-        self.window.bind("mouse_released", self._mouse_released)
+        self.window.bind("mouse_release", self._mouse_release)
+
         self.hide()
 
         self.skip = False
@@ -35,8 +35,9 @@ class SkPopup(SkCard):
         else:
             height = None
         self.fixed(**kwargs, width=width, height=height)
+        self.trigger("popup", SkEvent(self, "popup"))
 
-    def _mouse_released(self, event: SkEvent = None):
+    def _mouse_release(self, event: SkEvent = None):
         if not self.is_focus:
             self.hide()
 
