@@ -1,14 +1,11 @@
 import typing
 from functools import cache
-from typing import Any, Literal
 
-import glfw
 import skia
 
-from ..event import SkEvent, SkEventHanding
+from ..event import SkEvent, SkEventHandling
 from ..misc import SkMisc
-from ..styles.color import (SkColor, SkGradient, skcolor_to_color,
-                            style_to_color)
+from ..styles.color import SkColor, SkGradient, skcolor_to_color, style_to_color
 from ..styles.drop_shadow import SkDropShadow
 from ..styles.font import default_font
 from ..styles.theme import SkStyleNotFoundError, SkTheme, default_theme
@@ -16,7 +13,7 @@ from .appwindow import SkAppWindow
 from .window import SkWindow
 
 
-class SkWidget(SkEventHanding, SkMisc):
+class SkWidget(SkEventHandling, SkMisc):
 
     _instance_count = 0
 
@@ -31,7 +28,7 @@ class SkWidget(SkEventHanding, SkMisc):
         parent,
         *,
         cursor: str = "arrow",
-        style: str = "SkWidget",
+        style_name: str = "SkWidget",
         font: skia.Font | None = default_font,
         disabled: bool = False,
     ) -> None:
@@ -42,10 +39,11 @@ class SkWidget(SkEventHanding, SkMisc):
         :param cursor: Cursor style
         """
 
-        SkEventHanding.__init__(self)
+        SkEventHandling.__init__(self)
 
-        self.parent = parent
-        self.style = style
+        self.focused_redraw: bool = False
+        self.parent: SkWidget = parent
+        self.style_name: str = style_name
 
         try:
             self.window: SkWindow | SkAppWindow = (
@@ -55,39 +53,32 @@ class SkWidget(SkEventHanding, SkMisc):
             )
             self.application = self.window.application
         except AttributeError:
-            raise AttributeError(
-                f"Parent component is not a SkWindow-based object. {self.parent}"
-            )
+            raise AttributeError(f"Parent component is not a SkWindow-based object. {self.parent}")
         self.anti_alias = self.window.anti_alias
-        self.id = (
-            self.window.id
-            + "."
-            + self.__class__.__name__
-            + str(self._instance_count + 1)
-        )
+        self.id = self.window.id + "." + self.__class__.__name__ + str(self._instance_count + 1)
         SkWidget._instance_count += 1
 
-        self.events = {
-            "resize": dict(),
-            "move": dict(),
-            "mouse_move": dict(),
-            "mouse_motion": dict(),
-            "mouse_enter": dict(),
-            "mouse_leave": dict(),
-            "mouse_pressed": dict(),
-            "mouse_released": dict(),
-            "focus_gain": dict(),
-            "focus_loss": dict(),
-            "key_pressed": dict(),
-            "key_released": dict(),
-            "key_repeated": dict(),
-            "double_click": dict(),
-            "char": dict(),
-            "click": dict(),
-            "configure": dict(),
-            "update": dict(),
-            "scroll": dict(),
-        }
+        # self.task = {
+        #     "resize": dict(),
+        #     "move": dict(),
+        #     "mouse_move": dict(),
+        #     "mouse_motion": dict(),
+        #     "mouse_enter": dict(),
+        #     "mouse_leave": dict(),
+        #     "mouse_press": dict(),
+        #     "mouse_release": dict(),
+        #     "focus_gain": dict(),
+        #     "focus_loss": dict(),
+        #     "key_press": dict(),
+        #     "key_release": dict(),
+        #     "key_repeated": dict(),
+        #     "double_click": dict(),
+        #     "char": dict(),
+        #     "click": dict(),
+        #     "configure": dict(),
+        #     "update": dict(),
+        #     "scroll": dict(),
+        # }
 
         # Mouse events
         buttons = [
@@ -98,13 +89,13 @@ class SkWidget(SkEventHanding, SkMisc):
             "b2",
             "b3",
         ]  # Left Right Middle
-        button_states = ["pressed", "released", "motion", "move"]
+        button_states = ["press", "release", "motion", "move"]
 
-        for button in buttons:
-            for state in button_states:
-                self.event_generate(f"{button}_{state}")
+        # for button in buttons:
+        #     for state in button_states:
+        #         self.trigger(f"mouse_{state}[{button}]")
 
-        self.attributes: dict[str, Any] = {
+        self.attributes: dict[str, typing.Any] = {
             "cursor": cursor,
             "theme": None,
             "dwidth": 100,  # default width
@@ -146,27 +137,35 @@ class SkWidget(SkEventHanding, SkMisc):
 
         self.layout_config: dict[str, dict] = {"none": {}}
 
-        try:
+        if "SkContainer" in SkMisc.sk_get_type(self.parent):
             self.parent.add_child(self)
-        except TypeError:
+        else:
             raise TypeError("Parent component is not a SkContainer-based object.")
 
         # Events-related
         self.is_mouse_floating: bool = False
-        self.is_mouse_pressed: bool = False
         self.is_focus: bool = False
         self.gradient = SkGradient()
         self.button: typing.Literal[0, 1, 2] = 0
         self.click_time: float | int = 0
+        self.need_redraw: bool = False
 
-        def _on_mouse(event: SkEvent):
-            self.mouse_x = event.x
-            self.mouse_y = event.y
+        def _on_motion(event: SkEvent):
+            self.mouse_x = event["x"]
+            self.mouse_y = event["y"]
 
-        self.bind("mouse_enter", _on_mouse)
-        self.bind("mouse_motion", _on_mouse)
+        def _draw(event: SkEvent):
+            self.update(redraw=True)
 
-        self.bind("b1_released", self._click)
+        self.bind("mouse_enter", _draw)
+        self.bind("mouse_leave", _draw)
+        self.bind("mouse_press", _draw)
+        self.bind("mouse_motion", _on_motion)
+
+        self.bind("mouse_release", self._on_mouse_release)
+
+    def __str__(self):
+        return self.id
 
     # endregion
 
@@ -186,9 +185,10 @@ class SkWidget(SkEventHanding, SkMisc):
 
         update_pos()
 
-        self.event_trigger(
+        self.trigger(
             "move",
             SkEvent(
+                widget=self,
                 event_type="move",
                 x=self._x,
                 y=self._y,
@@ -197,28 +197,34 @@ class SkWidget(SkEventHanding, SkMisc):
             ),
         )
 
-    def _click(self, event) -> None:
-        """
-        Check click event (not pressed)
+    def _on_mouse_release(self, event) -> None:
+        if self.is_mouse_floating:
+            self.update(redraw=True)
+            self.trigger("click", event)
+            time = self.time()
 
-        :return: None
-        """
-        if self.button != 1:
-            if self.is_mouse_floating:
-
-                self.event_trigger("click", event)
-                time = self.time()
-
-                if self.click_time + self.cget("double_click_interval") > time:
-                    self.event_trigger("double_click", event)
-                    self.click_time = 0
-                else:
-                    self.click_time = time
+            if self.click_time + self.cget("double_click_interval") > time:
+                self.trigger("double_click", event)
+                self.click_time = 0
+            else:
+                self.click_time = time
 
     # endregion
 
     # region Draw the widget 绘制组件
 
+    def update(self, redraw: bool | None = None) -> None:
+        self.trigger("update", SkEvent(widget=self, event_type="update"))
+        if redraw is not None:
+            self.need_redraw = redraw
+
+        if "SkContainer" in SkMisc.sk_get_type(self):
+            from .container import SkContainer
+
+            SkContainer.update(self)
+
+        self._pos_update()
+
     def draw(self, canvas: skia.Canvas) -> None:
         """Execute the widget rendering and subwidget rendering
 
@@ -252,6 +258,8 @@ class SkWidget(SkEventHanding, SkMisc):
             self.update_layout(None)
             self.draw_children(canvas)
 
+        self.trigger("redraw", SkEvent(self, "redraw"))
+
     def draw_widget(self, canvas: skia.Canvas, rect: skia.Rect) -> None:
         """Execute the widget rendering
 
@@ -328,9 +336,7 @@ class SkWidget(SkEventHanding, SkMisc):
         def cache_paint(anti_alias, fg_):
             return skia.Paint(AntiAlias=anti_alias, Color=fg_)
 
-        text_paint = cache_paint(
-            self.anti_alias, skcolor_to_color(style_to_color(fg, self.theme))
-        )
+        text_paint = cache_paint(self.anti_alias, skcolor_to_color(style_to_color(fg, self.theme)))
 
         text_width = self.measure_text(text)
 
@@ -342,9 +348,7 @@ class SkWidget(SkEventHanding, SkMisc):
             draw_x = rect.left()
 
         metrics = self.metrics
-        draw_y = (
-            rect.top() + rect.height() / 2 - (metrics.fAscent + metrics.fDescent) / 2
-        )
+        draw_y = rect.top() + rect.height() / 2 - (metrics.fAscent + metrics.fDescent) / 2
 
         if bg:
             bg = skcolor_to_color(style_to_color(bg, self.theme))
@@ -430,30 +434,6 @@ class SkWidget(SkEventHanding, SkMisc):
                 )
         return None
 
-    def _rect_path(
-        self,
-        rect: skia.Rect,
-        radius: int | tuple[int, int, int, int] = 0,
-    ):
-        rrect: skia.RRect = skia.RRect.MakeRect(skia.Rect.MakeLTRB(*rect))
-        radii: tuple[
-            tuple[int, int], tuple[int, int], tuple[int, int], tuple[int, int]
-        ] = self.unpack_radius(radius)
-        # 设置每个角的半径（支持X/Y不对称）
-        rrect.setRectRadii(
-            skia.Rect.MakeLTRB(*rect),
-            [
-                skia.Point(*radii[0]),  # 左上
-                skia.Point(*radii[1]),  # 右上
-                skia.Point(*radii[2]),  # 右下
-                skia.Point(*radii[3]),  # 左下
-            ],
-        )
-
-        path = skia.Path()
-        path.addRRect(rrect)
-        return path
-
     def _draw_rect(
         self,
         canvas: skia.Canvas,
@@ -462,11 +442,9 @@ class SkWidget(SkEventHanding, SkMisc):
         bg: str | SkColor | int | None | tuple[int, int, int, int] = None,
         bd: str | SkColor | int | None | tuple[int, int, int, int] = None,
         width: int | float = 0,
-        bd_shadow: (
-            None | tuple[int | float, int | float, int | float, int | float, str]
-        ) = None,
-        bd_shader: None | Literal["linear_gradient"] = None,
-        bg_shader: None | Literal["linear_gradient"] = None,
+        bd_shadow: None | tuple[int | float, int | float, int | float, int | float, str] = None,
+        bd_shader: None | typing.Literal["linear_gradient"] = None,
+        bg_shader: None | typing.Literal["linear_gradient"] = None,
     ):
         """Draw the frame
 
@@ -480,10 +458,17 @@ class SkWidget(SkEventHanding, SkMisc):
         :param bd_shader: The shader of the border
 
         """
-        is_custom_radius = isinstance(radius, tuple | list)
-        if is_custom_radius:
-            path = self._rect_path(rect, radius)
-
+        radius = self.unpack_radius(radius)
+        rrect = skia.RRect()
+        rrect.setRectRadii(
+            skia.Rect.MakeLTRB(*rect),
+            [
+                skia.Point(*radius[0]),  # 左上
+                skia.Point(*radius[1]),  # 右上
+                skia.Point(*radius[2]),  # 右下
+                skia.Point(*radius[3]),  # 左下
+            ],
+        )
         if bg:
             bg_paint = skia.Paint(
                 AntiAlias=self.anti_alias,
@@ -504,10 +489,7 @@ class SkWidget(SkEventHanding, SkMisc):
                             config=bg_shader["linear_gradient"],
                             paint=bg_paint,
                         )
-            if is_custom_radius:
-                canvas.drawPath(path, bg_paint)
-            else:
-                canvas.drawRoundRect(rect, radius, radius, bg_paint)
+            canvas.drawRRect(rrect, bg_paint)
         if bd and width > 0:
             bd_paint = skia.Paint(
                 AntiAlias=self.anti_alias,
@@ -526,10 +508,9 @@ class SkWidget(SkEventHanding, SkMisc):
                             config=bd_shader["linear_gradient"],
                             paint=bd_paint,
                         )
-            if is_custom_radius:
-                canvas.drawPath(path, bd_paint)
-            else:
-                canvas.drawRoundRect(rect, radius, radius, bd_paint)
+                        # print(bd_shader["linear_gradient"])
+            canvas.drawRRect(rrect, bd_paint)
+        return rrect
 
     def _draw_circle(
         self,
@@ -540,11 +521,9 @@ class SkWidget(SkEventHanding, SkMisc):
         bg: str | SkColor | int | None | tuple[int, int, int, int] = None,
         bd: str | SkColor | int | None | tuple[int, int, int, int] = None,
         width: int | float = 0,
-        bd_shadow: (
-            None | tuple[int | float, int | float, int | float, int | float, str]
-        ) = None,
-        bd_shader: None | Literal["linear_gradient"] = None,
-        bg_shader: None | Literal["linear_gradient"] = None,
+        bd_shadow: None | tuple[int | float, int | float, int | float, int | float, str] = None,
+        bd_shader: None | typing.Literal["linear_gradient"] = None,
+        bg_shader: None | typing.Literal["linear_gradient"] = None,
     ):
         """Draw the circle
 
@@ -624,9 +603,7 @@ class SkWidget(SkEventHanding, SkMisc):
                     for key, value in bg.items():
                         match key.lower():
                             case "color":
-                                _bg = skcolor_to_color(
-                                    style_to_color(value, self.theme)
-                                )
+                                _bg = skcolor_to_color(style_to_color(value, self.theme))
                                 bg_paint.setColor(_bg)
                             case "lg" | "linear_gradient":
                                 self.gradient.linear(
@@ -649,9 +626,7 @@ class SkWidget(SkEventHanding, SkMisc):
         fg=skia.ColorGRAY,
         width: int = 1,
         shader: None | typing.Literal["linear_gradient"] = None,
-        shadow: (
-            None | tuple[int | float, int | float, int | float, int | float, str]
-        ) = None,
+        shadow: None | tuple[int | float, int | float, int | float, int | float, str] = None,
     ):
         fg = skcolor_to_color(style_to_color(fg, self.theme))
         paint = skia.Paint(Color=fg, StrokeWidth=width)
@@ -664,14 +639,12 @@ class SkWidget(SkEventHanding, SkMisc):
                         paint=paint,
                     )
         if shadow:
-            shadow = SkDropShadow(config_list=shadow)
-            shadow.draw(paint)
+            _ = SkDropShadow(config_list=shadow)
+            _.draw(paint)
         canvas.drawLine(x0, y0, x1, y1, paint)
 
     @staticmethod
-    def _draw_image_rect(
-        canvas: skia.Canvas, rect: skia.Rect, image: skia.Image
-    ) -> None:
+    def _draw_image_rect(canvas: skia.Canvas, rect: skia.Rect, image: skia.Image) -> None:
         canvas.drawImageRect(image, rect, skia.SamplingOptions(), skia.Paint())
 
     @staticmethod
@@ -682,6 +655,28 @@ class SkWidget(SkEventHanding, SkMisc):
 
     # region Widget attribute configs 组件属性配置
 
+    def is_entered(self, mouse_x, mouse_y) -> bool:
+        """Check if within the widget's bounds.
+        【检查是否进入组件范围（即使超出父组件，其超出部分进入仍判定为True）】
+        :param widget: SkWidget
+        :param event: SkEvent
+        :return bool:
+        """
+        if self.visible:
+            cx, cy = self.canvas_x, self.canvas_y
+            x, y = mouse_x, mouse_y
+            width, height = self.width, self.height
+            return cx <= x <= cx + width and cy <= y <= cy + height
+        return False
+
+    @property
+    def is_mouse_press(self):
+        return (
+            self.is_mouse_floating
+            and self.window.is_mouse_press
+            and self.window.pressing_widget is self
+        )
+
     @property
     def dwidth(self):
         _width = self.cget("dwidth")
@@ -708,10 +703,6 @@ class SkWidget(SkEventHanding, SkMisc):
         font: skia.Font = self.cget("font")
         return font.measureText(text, *args)
 
-    def update(self):
-        self._pos_update()
-        self.post()
-
     @property
     def x(self):
         return self._x
@@ -766,7 +757,7 @@ class SkWidget(SkEventHanding, SkMisc):
         self._root_y = value
         self._pos_update()
 
-    def get_attribute(self, attribute_name: str) -> Any:
+    def get_attribute(self, attribute_name: str) -> typing.Any:
         """Get attribute of a widget by name.
 
         :param attribute_name: attribute name
@@ -782,7 +773,7 @@ class SkWidget(SkEventHanding, SkMisc):
         :return: self
         """
         self.attributes.update(**kwargs)
-        self.event_trigger("configure", SkEvent(event_type="configure", widget=self))
+        self.trigger("configure", SkEvent(event_type="configure", widget=self))
         return self
 
     configure = config = set_attribute
@@ -800,8 +791,11 @@ class SkWidget(SkEventHanding, SkMisc):
 
     def read_size(self, selector: str):
         try:
+            # print("Get style: ", selector, "size")
             size = self.theme.get_style_attr(selector, "size")
-            self.config(dwidth=size[0], dheight=size[1])
+            # print(self.id, size)
+            if size:
+                self.config(dwidth=size[0], dheight=size[1])
         except SkStyleNotFoundError:
             pass
 
@@ -813,10 +807,15 @@ class SkWidget(SkEventHanding, SkMisc):
         """
         self.theme = new_theme
         self.styles = self.theme.styles
-        self.read_size(self.style)
+        self.read_size(self.style_name)
         if hasattr(self, "children"):
+            child: SkWidget
+            self.children: list
             for child in self.children:
-                child.apply_theme(new_theme)
+                if child.theme.is_special:
+                    child.theme.set_parent(new_theme.name)
+                else:
+                    child.apply_theme(new_theme)
 
     # endregion
 
@@ -902,7 +901,7 @@ class SkWidget(SkEventHanding, SkMisc):
                     "height": height,
                 }
             }
-            self.parent.add_fixed_child(self)
+            self.parent.add_layer3_child(self)
 
         return self
 
@@ -924,18 +923,22 @@ class SkWidget(SkEventHanding, SkMisc):
                 "y": y,
             }
         }
-        self.parent.add_floating_child(self)
+        self.parent.add_layer2_child(self)
 
         return self
 
+    floating = place
+
     def grid(
         self,
         row: int = 0,  # 行 横
-        column: int = 0,  # 列 竖
+        column: int = 1,  # 列 竖
         rowspan: int = 1,
         columnspan: int = 1,
-        padx: int | float | None = None,
-        pady: int | float | None = None,
+        padx: int | float | tuple[int | float, int | float] | None = 5,
+        pady: int | float | tuple[int | float, int | float] | None = 5,
+        ipadx: int | float | tuple[int | float, int | float] | None = 0,
+        ipady: int | float | tuple[int | float, int | float] | None = 0,
     ):
 
         self.show()
@@ -947,9 +950,11 @@ class SkWidget(SkEventHanding, SkMisc):
                 "columnspan": columnspan,
                 "padx": padx,
                 "pady": pady,
+                "ipadx": ipadx,
+                "ipady": ipady,
             }
         }
-        self.parent.add_layout_child(self)
+        self.parent.add_layer1_child(self)
 
         return self
 
@@ -978,13 +983,13 @@ class SkWidget(SkEventHanding, SkMisc):
                 "expand": expand,
             }
         }
-        self.parent.add_layout_child(self)
+        self.parent.add_layer1_child(self)
 
         return self
 
     def box(
         self,
-        side: Literal["top", "bottom", "left", "right"] = "top",
+        side: typing.Literal["top", "bottom", "left", "right"] = "top",
         padx: int | float | tuple[int | float, int | float] = 5,
         pady: int | float | tuple[int | float, int | float] = 5,
         ipadx: int | float | tuple[int | float, int | float] | None = None,
@@ -1025,7 +1030,7 @@ class SkWidget(SkEventHanding, SkMisc):
                     "expand": expand,
                 }
             }
-            self.parent.add_layout_child(self)
+            self.parent.add_layer1_child(self)
         if ipadx:
             self.ipadx = ipadx
         if ipady:
@@ -1040,15 +1045,14 @@ class SkWidget(SkEventHanding, SkMisc):
         """
         Set focus
         """
-        if self.focusable:
+        if self.focusable and not self.cget("disabled"):
             if not self.is_focus:
-                self.window.focus_get().event_trigger(
-                    "focus_loss", SkEvent(event_type="focus_loss")
-                )
+                self.window.focus_get().trigger("focus_loss", SkEvent(event_type="focus_loss"))
                 self.window.focus_get().is_focus = False
                 self.window.focus_widget = self
                 self.is_focus = True
-                self.event_trigger("focus_gain", SkEvent(event_type="focus_gain"))
+
+                self.trigger("focus_gain", SkEvent(event_type="focus_gain"))
 
     def focus_get(self) -> None:
         """
